@@ -2,18 +2,18 @@
 test_that("pulling SDFs via 'name' is succesful", {
   temp_dir <- tempdir(check = TRUE)
 
-  tmp <- try(get_sdf(
-    identifier = "aspirin",
-    namespace = "name",
-    path = temp_dir,
-    file_name = "file"
-  ))
+  expect_invisible({
+    tmp <- try(get_sdf(
+      identifier = "aspirin",
+      namespace = "name",
+      path = temp_dir
+    ))
+  })
 
   expect_true(file.exists(temp_dir))
-  expect_true(file.exists(file.path(temp_dir, "file.sdf")))
+  expect_true(file.exists(tmp))
 
-  file.remove(file.path(temp_dir, "file.sdf"))
-  file.remove(temp_dir)
+  file.remove(tmp)
 })
 
 test_that("pulling SDFs via 'cid' is succesful", {
@@ -30,7 +30,6 @@ test_that("pulling SDFs via 'cid' is succesful", {
   expect_true(file.exists(file.path(temp_dir, "file.sdf")))
 
   file.remove(file.path(temp_dir, "file.sdf"))
-  file.remove(temp_dir)
 })
 
 test_that("no SDF file saved for unknown/incorrect identifiers", {
@@ -46,23 +45,19 @@ test_that("no SDF file saved for unknown/incorrect identifiers", {
   })
 
   expect_null(tmp)
-
-  file.remove(temp_dir)
 })
 
-# test_that("save SDF files to temporary working directory when path is not specified.", {
-#
-#   tmp <- try(get_sdf(
-#     identifier = "aspirin",
-#     namespace = "name",
-#     file_name = "file",
-#     path = NULL
-#   ))
-#
-#   default_path <- temp_dir
-#   expect_true(file.exists(default_path))
-#   expect_true(file.exists(file.path(default_path, "file.sdf")))
-#
-#   file.remove(file.path(default_path, "file.sdf"))
-# })
+test_that("save SDF files to temporary working directory when path is not specified.", {
+  tmp <- try(get_sdf(
+    identifier = "aspirin",
+    namespace = "name",
+    file_name = "file",
+    path = NULL
+  ))
+
+  default_path <- tempdir(check = TRUE)
+  expect_true(file.exists(default_path))
+  expect_true(file.exists(file.path(default_path, "file.sdf")))
+  file.remove(file.path(default_path, "file.sdf"))
+})
 
